import { useAjax } from "@/Hook/useAjax"
import { AD_STATUS_ENUM, BID_MODE_ENUM } from "@/pages/iaaData/const"
import { getAppListApi, getPutUserListApi } from "@/services/iaaData"
import { Button, Col, Form, Row, Space, DatePicker, Select, Input, InputNumber } from "antd"
import { RangePickerProps } from "antd/lib/date-picker"
import React, { useEffect, useState } from "react"


interface Props {
    onChange?: (data: any) => void
    /** 默认值 */
    initialValues?: any

    /** 是否开启 广告账号 搜索 */
    isAccountId?: boolean
    /** 是否开启 当前出价 搜索 */
    isCpaBid?: boolean
    /** 是否开启 广告名称 搜索 */
    isPromotionName?: boolean
    /** 是否开启 广告ID 搜索 */
    isPromotionId?: boolean

    /** 是否开启 投手 搜索 */
    isPutUserIdList?: boolean
    /** 是否开启 出价方式 搜索 */
    isPricing?: boolean,
    /** 是否开启 广告状态 搜索 */
    isStatus?: boolean,
    /** 是否开启 删除状态 搜索 */
    isDeleted?: boolean,

    /** 是否开启 日期 搜索 */
    day1?: RangePickerProps
    /** 是否开启 日期 搜索 */
    day2?: RangePickerProps
    /** 是否开启 日期 搜索 */
    day3?: RangePickerProps
}
/**
 * 游戏数据系统 请求参数
 * @returns 
 */
const QueryForm: React.FC<Props> = (props) => {

    /**************************/
    const {
        onChange, initialValues, isAccountId, isPromotionName, isPromotionId, isCpaBid, isPutUserIdList, isPricing, isStatus, isDeleted, day1, day2, day3
    } = props
    const [form] = Form.useForm()
    const [putUserList, setPutUserList] = useState<{ label: string, value: string }[]>([])

    const getPutUserList = useAjax(() => getPutUserListApi())
    /**************************/

    useEffect(() => {
        if (isPutUserIdList) {
            getPutUserList.run().then(res => {
                if (res?.data) {
                    setPutUserList(Object.keys(res.data).map(key => ({ value: key, label: res.data[key] })))
                }
            })
        }
    }, [isPutUserIdList])

    const onFinish = (data: any) => {
        console.log('更新了字段---->', data);
        onChange && onChange(data)
    }

    return <Form layout="inline" className='queryForm' initialValues={initialValues} name="basic" form={form} onFinish={onFinish}>
        <Row gutter={[0, 6]}>

            {/* 广告账号 */}
            {isAccountId && <Col><Form.Item name='accountId'>
                <Input placeholder="广告账号" style={{ width: 150 }} />
            </Form.Item></Col>}
            
            {/* 广告名称 */}
            {isPromotionName && <Col><Form.Item name='promotionName'>
                <Input placeholder="广告名称" style={{ width: 150 }} />
            </Form.Item></Col>}

            {/* 广告ID */}
            {isPromotionId && <Col><Form.Item name='promotionId'>
                <Input placeholder="广告ID" style={{ width: 150 }} />
            </Form.Item></Col>}

            {/* 出价 */}
            {isCpaBid && <Col><Form.Item name='cpaBid'>
                <InputNumber placeholder="出价" style={{ width: 120 }} />
            </Form.Item></Col>}

            {/* 投手 */}
            {isPutUserIdList && <Col><Form.Item name='putUserIdList'>
                <Select
                    showSearch
                    allowClear
                    mode="multiple"
                    style={{ width: 120 }}
                    placeholder={'投手'}
                    filterOption={(input, option) =>
                        (option?.label as any)?.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                    loading={getPutUserList.loading}
                    options={putUserList}
                />
            </Form.Item></Col>}

            {/* 出价方式 */}
            {isPricing && <Col><Form.Item name='pricing'>
                <Select
                    showSearch
                    allowClear
                    style={{ width: 120 }}
                    placeholder={'出价方式'}
                    filterOption={(input, option) =>
                        (option?.label as any)?.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                    options={Object.keys(BID_MODE_ENUM).map(key => ({ label: BID_MODE_ENUM[key as keyof typeof BID_MODE_ENUM], value: key }))}
                />
            </Form.Item></Col>}


            {/* 广告状态 */}
            {isStatus && <Col><Form.Item name='status'>
                <Select
                    showSearch
                    allowClear
                    style={{ width: 120 }}
                    placeholder={'广告状态'}
                    filterOption={(input, option) =>
                        (option?.label as any)?.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                    options={Object.keys(AD_STATUS_ENUM).map(key => ({ label: AD_STATUS_ENUM[key as keyof typeof AD_STATUS_ENUM], value: key }))}
                />
            </Form.Item></Col>}

            {/* 是否退游 */}
            {isDeleted && <Col><Form.Item name='deleted'>
                <Select
                    showSearch
                    allowClear
                    style={{ width: 120 }}
                    placeholder={'是否删除？'}
                    filterOption={(input, option) =>
                        (option?.children as any)?.toLowerCase().indexOf(input.toLowerCase()) >= 0
                    }
                >
                    <Select.Option value={true}>是</Select.Option>
                    <Select.Option value={false}>否</Select.Option>
                </Select>
            </Form.Item></Col>}

            {/* 日期选择框 */}
            {day1 && <Col><Form.Item name='day1'>
                <DatePicker.RangePicker style={{ width: 250 }} {...day1} />
            </Form.Item></Col>}

            {/* 日期选择框 */}
            {day2 && <Col><Form.Item name='day2'>
                <DatePicker.RangePicker style={{ width: 250 }} {...day2} />
            </Form.Item></Col>}

            {/* 日期选择框 */}
            {day3 && <Col><Form.Item name='day3'>
                <DatePicker.RangePicker style={{ width: 250 }} {...day3} />
            </Form.Item></Col>}

            <Col>
                <Space>
                    <Button type="primary" htmlType="submit">搜索</Button>
                    <Button onClick={() => form.resetFields()}>重置</Button>
                </Space>
            </Col>
        </Row>
    </Form>
}


export default React.memo(QueryForm)