import { useAjax } from "@/Hook/useAjax"
import { Button, Drawer } from "antd"
import React, { useEffect, useState } from "react"
import columns12 from './tableConfigDay'
import QueryForm from "@/components/QueryForm"
import { CloseOutlined } from "@ant-design/icons"
import TablePro from "@/components/TablePro"
import moment from "moment"
import { getGDTDailyListApi } from "@/services/iaaData"

interface Props {
    queryForm: {
        costDayBegin?: string,
        costDayEnd?: string
    }
    iaaApp: string,
    adName: string,
    promotionId?: number
    onClose?: () => void
    visible?: boolean
}

/**
 * 广告每日监控
 * @returns 
 */
const DayAd: React.FC<Props> = ({ iaaApp, adName, queryForm, promotionId, onClose, visible }) => {

    /***********************************/
    const [data, setData] = useState<{ pageSize: number, pageNum: number, sortFiled?: string, sortType?: string }>({ pageNum: 1, pageSize: 30 })
    const [date, setDate] = useState<[string, string] | undefined>((queryForm?.costDayBegin && queryForm.costDayEnd) ? [queryForm.costDayBegin, queryForm.costDayEnd] : undefined)
    const getGDTDailyList = useAjax((params) => getGDTDailyListApi(params))
    /***********************************/

    useEffect(() => {
        let params: any = {}
        const [appId, productType] = iaaApp.split('||')
        if (promotionId) {
            params.promotionId = promotionId
        }
        if (date && date?.length > 0) {
            params.costDayBegin = date[0]
            params.costDayEnd = date[1]
        } else {
            delete params?.costDayBegin
            delete params?.costDayEnd
        }
        getGDTDailyList.run({ ...params, ...data, appId, productType })
    }, [promotionId, queryForm, data, date, iaaApp])

    return <Drawer title={<div style={{ display: 'flex', justifyContent: 'space-between' }}><span>{`${adName} 腾讯广告每日数据`}</span> <Button type="text" icon={<CloseOutlined />} onClick={() => onClose?.()}></Button> </div>} closable={false} placement="right" width={'90%'} onClose={onClose} open={visible}>
        <TablePro
            leftChild={<QueryForm
                initialValues={{ day1: queryForm?.costDayBegin ? [moment(queryForm?.costDayBegin), moment(queryForm?.costDayEnd)] : null }}
                onChange={(data: any) => {
                    const { day1 } = data
                    if (day1 && day1?.length === 2) {
                        setDate([moment(day1[0]).format('YYYY-MM-DD'), moment(day1[1]).format('YYYY-MM-DD')])
                    } else {
                        setDate(undefined)
                    }
                }}
                day1={{ placeholder: ['消耗日期开始', '消耗日期结束'] }}
            />}
            scroll={{ x: 1000, y: 600 }}
            ajax={getGDTDailyList}
            loading={getGDTDailyList.loading}
            fixed={{ left: 3, right: 0 }}
            dataSource={getGDTDailyList?.data?.data?.records?.map((item: any, index: number) => ({ ...item, id: Number(data.pageNum.toString() + index.toString()) }))}
            page={getGDTDailyList?.data?.data?.current || 1}
            pageSize={getGDTDailyList?.data?.data?.size || 20}
            total={getGDTDailyList?.data?.data?.total || 0}
            title='腾讯广告每日监控'
            onChange={(pagination: any, _: any, sortData: any) => {
                let { current, pageSize } = pagination
                let newQueryForm = JSON.parse(JSON.stringify(data))
                if (sortData && sortData?.order) {
                    newQueryForm['sortAsc'] = sortData?.order === 'ascend' ? true : false
                    newQueryForm['sortFiled'] = sortData?.field
                } else {
                    delete newQueryForm['sortAsc']
                    delete newQueryForm['sortFiled']
                }
                newQueryForm.pageNum = current || newQueryForm.pageNum
                newQueryForm.pageSize = pageSize || newQueryForm.pageSize
                setData({ ...newQueryForm })
            }}
            config={columns12()}
            configName={'腾讯广告每日监控'}
        />
    </Drawer>
}

export default React.memo(DayAd)