import { PlusOutlined } from "@ant-design/icons";
import ProTable, { ActionType } from "@ant-design/pro-table";
import { Button } from "antd";
import React, { useEffect, useRef, useState } from "react"
import tableConfig from "./tableConfig";
import { useAjax } from "@/Hook/useAjax";
import { getMenuUserListApi } from "@/services/iaaSystem/power";
import { getAppAllApi, getAppListApi } from "@/services/iaaSystem/application";
import { DefaultOptionType } from "antd/lib/select";
import ModalApp from "./modalApp";

/**
 * 应用管理
 * @returns 
 */
const Application: React.FC = () => {
    /*******************************************/
    const actionRef = useRef<ActionType>();
    const [visible, setVisible] = useState<boolean>(false)
    const [initialValues, setInitialValues] = useState<any>()
    const [appList, setAppList] = useState<DefaultOptionType[]>([])
    const [appObj, setAppObj] = useState<any>({})
    const [userList, setUserList] = useState<DefaultOptionType[]>([])
    const [userObj, setUserObj] = useState<any>({})


    const getAppList = useAjax((params) => getAppListApi(params), { type: 'table' })
    const getMenuUserList = useAjax(() => getMenuUserListApi())
    const getAppAll = useAjax(() => getAppAllApi())
    /*******************************************/

    useEffect(() => {
        getMenuUserList.run().then(res => {
            if (res?.data) {
                let newUserList: DefaultOptionType[] = []
                let newUserObj: any = {}
                Object.keys(res.data).forEach(key => {
                    newUserList.push({ label: res.data[key], value: key })
                    newUserObj[key] = {
                        text: res.data[key]
                    }
                })
                setUserList(newUserList)
                setUserObj(newUserObj)
            }
        })
        getAppAll.run().then(res => {
            if (res?.data) {
                let newAppList: DefaultOptionType[] = []
                let newAppObj: any = {}
                res.data.forEach((item: { name: any; id: any; }) => {
                    newAppList.push({ label: item.name, value: item.id })
                    newAppObj[item.id] = {
                        text: item.name
                    }
                })
                setAppList(newAppList)
                setAppObj(newAppObj)
            }
        })
    }, [])

    /**
     * 修改
     * @param data 
     */
    const handleEdit = (data: any) => {
        console.log(data)
        setInitialValues(data)
        setVisible(true)
    }

    return <>
        <ProTable<any>
            columns={tableConfig(handleEdit, userObj, appObj)}
            actionRef={actionRef}
            cardBordered
            request={async (params, sort, filter) => {
                console.log(sort, filter);
                return await getAppList.run(params)
            }}
            editable={{
                type: 'multiple',
            }}
            rowKey="id"
            search={{
                labelWidth: 'auto',
            }}
            headerTitle={<strong>应用管理</strong>}
            toolBarRender={() => [
                <Button type="primary" onClick={() => {
                    setVisible(true)
                }}>
                    <PlusOutlined />
                    新建
                </Button>
            ]}
        />

        {/* 新增修改 */}
        {visible && <ModalApp
            initialValues={initialValues}
            appAllList={appList}
            userList={userList}
            visible={visible}
            onChange={() => {
                setVisible(false)
                setInitialValues(undefined)
                actionRef.current?.reload()
            }}
            onClose={() => {
                setVisible(false)
                setInitialValues(undefined)
            }}
        />}
    </>
}

export default Application